#
# spec file for package dolphin-emu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define commit 8bad821019721b9b72701b495da95656ace5fea5
Name:           dolphin-emu
Version:        5.0.17995
Release:        5.2
Summary:        Dolphin, a GameCube and Wii Emulator
License:        (Apache-2.0 OR MIT) AND BSD-2-Clause AND libpng-2.0 AND GPL-2.0-or-later
URL:            https://dolphin-emu.org
# n=dolphin-emu && v=5.0.17995 && c=8bad821019721b9b72701b495da95656ace5fea5 && cd /tmp && git clone https://github.com/$n/dolphin.git $n && cd $n && git checkout $c && rm -rf .??* && cd .. && n=dolphin-emu && d=$n-$v && mv $n $d && f=$d.tar.xz && tar c --remove-files "$d" | xz -9e > "$f"
Source0:        %{name}-%{version}.tar.xz
Patch0:         %{name}-not-discord-presence.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel >= 5.9
BuildRequires:  mbedtls-devel < 3
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.9
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fmt) >= 6.0
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(miniupnpc)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(sfml-network)
BuildRequires:  pkgconfig(sfml-system)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xrandr)
Requires:       nintendo-gamecube-wiimote-udev-rules
ExclusiveArch:  x86_64 aarch64

%description
Dolphin is an emulator for two Nintendo video game consoles, GameCube and the Wii.
It allows PC gamers to enjoy games for these two consoles in full HD with several
enhancements such as compatibility with all PC controllers, turbo speed,
networked multiplayer, and more.
Most games run perfectly or with minor bugs.

%package -n nintendo-gamecube-wiimote-udev-rules
Summary:        Udev rules for Nintendo GameCube and Wiimote game controllers
Requires:       udev
BuildArch:      noarch

%description -n nintendo-gamecube-wiimote-udev-rules
This package contains udev rules for Nintendo GameCube and Wiimote game controllers.

%lang_package

%prep
%autosetup -p1
#Allow building with cmake macro. Build failed on aarch64 with optflags.
%ifarch x86_64
sed -i '/CMAKE_C.*_FLAGS/d' CMakeLists.txt
%endif
sed -i 's/minizip>=2.0.0/minizip/' CMakeLists.txt

%build
# FIXME: you should use the %%cmake macros
cmake . \
    -LA \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DCMAKE_C_COMPILER=gcc-12 \
    -DCMAKE_CXX_COMPILER=g++-12 \
    -DCMAKE_C_FLAGS="%{optflags}" \
    -DCMAKE_CXX_FLAGS="%{optflags}" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DDISTRIBUTOR=openSUSE \
    -DDOLPHIN_WC_BRANCH=beta \
    -DDOLPHIN_WC_DESCRIBE=%{version} \
    -DDOLPHIN_WC_REVISION=%{commit} \
    -DENABLE_ANALYTICS=OFF \
    -DENABLE_LTO=ON \
    -DENCODE_FRAMEDUMPS=OFF \
    -DUSE_DISCORD_PRESENCE=OFF \
    -DUSE_MGBA=OFF \
    -DUSE_SHARED_ENET=ON \
    -DXXHASH_FOUND=ON \
    -G Ninja
ninja -v

%install
DESTDIR=%{buildroot} ninja install
sed -i 's/^Exec=.*/Exec=%{name}/' %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dpm0644 Data/51-usb-device.rules %{buildroot}%{_udevrulesdir}/51-nintendo-gamecube-wiimote.rules
%fdupes -s %{buildroot}
%find_lang %{name}

%files lang -f %{name}.lang

%files
%defattr(0644,root,root,0755)
%license COPYING
%doc Readme.md
%attr(0755,root,root) %{_bindir}/%{name}*
%attr(0755,root,root) %{_bindir}/dolphin-tool
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.{png,svg}
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man6/%{name}*.6%{?ext_man}

%files -n nintendo-gamecube-wiimote-udev-rules
%{_udevrulesdir}/51-nintendo-gamecube-wiimote.rules

%changelog
* Mon Sep 11 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of the license based on the legaldb report.
  Add BSD-2-Clause AND libpng-2.0, and (Apache-2.0 OR MIT)
  aside from original GPL-2.0-or-later
* Sun Aug 20 2023 Илья Индиго <ilya@ilya.cf>
- Switched to gcc12 (boo#1210477).
- Removed file dolphin-emu-gcc13.patch.
* Fri May  5 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Limit build to mbedtls < 3.
* Wed Apr 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add dolphin-emu-gcc13.patch: Fix build using GCC 13. Patch
  imported based on https://github.com/GPUOpen-LibrariesAndSDKs/VulkanMemoryAllocator/pull/326
* Wed Dec 28 2022 Jannik Seiler <seil0@mosad.xyz>
- Updated to 5.0.17995 8bad821019721b9b72701b495da95656ace5fea5
  * Implement Missing Features for WiiConnect24 Support
  * Netplay: Redesign Wii Remote Data Exchange
  * Vulkan: Use VMA for memory allocations
  * Vulkan: Raise number of command buffers
  * Vulkan: Allocate descriptor pools as needed
  * Optimize GetVertexSize
  * Cache Vertex Sizes
  * Update EFB Peek Cache on Draw Done and Tokens
  * D3D12: Fix Numerous hangs
  * Add Dynamic Vertex Loaders for Ubershaders
  * Add Emulation of Pointsize/Linewidth in Vertex Shaders
  * Debugging: Add Support for Conditional Breakpoints
  * Add GBA TAS Window
  * Improve FPS/VPS Counting and Revamp Appearance
* Sun Nov 27 2022 Carsten Ziepke <kieltux@gmail.com>
- Fix building for openSUSE Leap 15.4 using gcc10-c++
* Fri Oct 14 2022 Jannik Seiler <seil0@mosad.xyz>
- Updated to 5.0.17269 48c9c224cf9f82f0f9f2690b7cc6283d7448480c
  * Added dolphin-emu-not-discord-presence.patch to fix build
    failure if discord presence is disabled.
  * Reduce pipeline compilation stutter through forcing FBFetch in ubershaders.
  * Added support for native motion/rumble with SDL2.
  * Added SD card folder syncing support.
  * Added flush command buffers after multiple EFB copies.
  * Added accurately handle the copy filter and gamma for EFB and XFB copies.
  * Added HLE broadband device.
  * Added support for libaesnd microcode.
  * Added support for NFS files.
* Fri Jul  8 2022 Илья Индиго <ilya@ilya.cf>
- Initialized 5.0.16793 3cd82b619388d0877436390093a6edc2319a6904
